# -*- coding: utf-8 -*-

# Licensed under the Apache License, Version 2.0 (the "License"); you may
# not use this file except in compliance with the License. You may obtain
# a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
# WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
# License for the specific language governing permissions and limitations
# under the License.


TRAITS = [
    # ref: https://en.wikipedia.org/wiki/Display_resolution
    'W320H240',
    'W640H480',
    'W800H600',
    'W1024H600',
    'W1024H768',
    'W1152H864',
    'W1280H720',
    'W1280H768',
    'W1280H800',
    'W1280H1024',
    'W1360H768',
    'W1366H768',
    'W1440H900',
    'W1600H900',
    'W1600H1200',
    'W1680H1050',
    'W1920H1080',
    'W1920H1200',
    'W2560H1440',
    'W2560H1600',
    'W3840H2160',
    'W7680H4320',
]
